@@ -8,14 +8,15 @@ use Exporter;
 our @ISA = qw(Exporter);
 
 our %EXPORT_TAGS = (
-	fortran => [ qw(log10 copysign) ],
 	compare => [ qw(generate_fltcmp generate_relational) ],
-	utility => [ qw(sign) ],
-	polynomial => [ qw(pl_evaluate pl_add pl_sub pl_div pl_mult pl_derivative pl_antiderivative) ],
+	fortran => [ qw(log10 copysign) ],
+	utility => [ qw(log10 copysign sign) ],
+	polynomial => [ qw(pl_evaluate pl_dxevaluate
+			pl_add pl_sub pl_div pl_mult
+			pl_derivative pl_antiderivative) ],
 );
 
 our @EXPORT_OK = (
-	@{ $EXPORT_TAGS{fortran} },
 	@{ $EXPORT_TAGS{compare} },
 	@{ $EXPORT_TAGS{utility} },
 	@{ $EXPORT_TAGS{polynomial} },
@@ -29,7 +30,11 @@ Math::Utils - Useful mathematical functions not in Perl.
 
 =head1 SYNOPSIS
 
-    use Math::Utils qw(:fortran);    # Functions originally from Fortran
+    use Math::Utils qw(:utility);    # Useful functions
+
+    $dir = sign($z - $w);
+
+    @ternaries = sign(@coefficients);
 
     #
     # $dist will be doubled negative or positive $offest, depending
@@ -69,14 +74,6 @@ or
     my(undef, undef,
         $approx_gt, undef, $approx_lt) = generate_relational(1.5e-5);
 
-or
-
-    use Math::Utils qw(:utility);    # Other useful functions
-
-    $dir = sign($z - $w);
-
-    @ternaries = sign(@coefficients);
-
 or
 
     use Math::Utils qw(:polynomial);    # Basic polynomial ops
@@ -100,6 +97,13 @@ grouped under.
 
 =head2 utility tag
 
+Useful, general-purpose functions, including those that originated in
+FORTRAN and were implemented in Perl in the module L<Math::Fortran>,
+by J. A. R. Williams.
+
+There is a name change -- copysign() was known as sign()
+in Math::Fortran.
+
 =head3 sign()
 
   $s = sign($x);
@@ -118,13 +122,6 @@ sub sign
 		($_[0] < 0)? -1: (($_[0] > 0)? 1: 0);
 }
 
-=head2 fortran tag
-
-These are functions that originated in FORTRAN, and were implemented
-in Perl in the module L<Math::Fortran>, by J. A. R. Williams.
-
-They are here with a name change -- copysign() was known as sign()
-in Math::Fortran.
 
 =head3 copysign()
 
@@ -311,6 +308,60 @@ sub pl_evaluate
 	return wantarray? @results: $results[0];
 }
 
+=head3 pl_dxevaluate(\@coefficients, $x);
+
+    ($y, $dy, $ddy) = pl_dxevaluate(\@coefficients, $x);
+
+Returns p(x), p'(x), and p"(x) of the polynomial for an
+x-value, using Horner's method. Note that unlike pl_evaluate()
+above, the function can only use one x-value.
+
+=cut
+
+sub pl_dxevaluate
+{
+	my($coef_ref, $x) = @_;
+	my(@coefficients) = @$coef_ref;
+	my $n = $#coefficients;
+	my $val = pop @coefficients;
+	my $d1val = $val * $n;
+	my $d2val = 0;
+
+	#
+	# Special case for the linear eq'n (the y = constant eq'n
+	# takes care of itself).
+	#
+	if ($n == 1)
+	{
+		$d1val = $val;
+		$val = $val * $x + $coefficients[0];
+	}
+	elsif ($n >= 2)
+	{
+		my $lastn = --$n;
+		$d2val = $d1val * $n;
+
+		#
+		# Loop through the coefficients, except for
+		# the linear and constant terms.
+		#
+		foreach my $c (reverse @coefficients[2..$lastn])
+		{
+			$val = $val * $x + $c;
+			$d1val = $d1val * $x + ($c *= $n--);
+			$d2val = $d2val * $x + ($c * $n);
+		}
+
+		#
+		# Handle the last two coefficients.
+		#
+		$d1val = $d1val * $x + $coefficients[1];
+		$val = ($val * $x + $coefficients[1]) * $x + $coefficients[0];
+	}
+
+	return ($val, $d1val, $d2val);
+}
+
 =head3 pl_add()
 
   $polyn_ref = pl_add(\@m, \@n);
